@@ -4,5 +4,9 @@ use strict;
 use base qw[
   JavaScript::MochiKit::Accessor
 ];
+use vars qw [ @Dependencies ];
+
+@Dependencies = qw [ Base ];
+
 
 1;
